@@ -1,10 +1,6 @@
 const wrapper = require('./TransmitterWrapper')
 
 class Transmitter {
-    static initialize() {
-        return wrapper.initialize()
-    }
-
     static sendCommand(messageArray) {
         return wrapper.sendCommand(messageArray)
     }
@@ -16,6 +12,10 @@ class Transmitter {
     static setConfigSource(configSource) {
         return wrapper.setConfigSource(configSource)
     }
+
+    static setJavonetWorkingDirectory(workingDirectory) {
+        return wrapper.setJavonetWorkingDirectory(workingDirectory)
+    }
 }
 
 module.exports = Transmitter
