@@ -1,12 +1,9 @@
 package Javonet::Core::Handler::CommandHandler::GetInstanceFieldHandler;
-use aliased 'Javonet::Core::Handler::PerlHandler' => 'PerlHandler';
 use strict;
 use warnings FATAL => 'all';
-use Moose;
 use lib 'lib';
-use lib 'data_seed';
+use Moose;
 use Nice::Try;
-use Data::Dumper;
 use aliased 'Javonet::Core::Exception::Exception' => 'Exception';
 extends 'Javonet::Core::Handler::CommandHandler::AbstractCommandHandler';
 
