@@ -1,10 +1,7 @@
 package Javonet::Sdk::Core::PerlCommandType;
 use strict;
 use warnings;
-use Exporter;
-
-our @ISA = qw(Exporter);
-our @EXPORT = qw(get_command_type);
+use Moose;
 
 my %command_type = (
     'Value'                     => 0,
@@ -41,9 +38,9 @@ my %command_type = (
     'AsRef'                     => 31,
     'AsOut'                     => 32,
     'GetRefValue'               => 33,
-
-
-
+    'EnableNamespace'           => 34,
+    'EnableType'                => 35,
+    'CreateNull'                => 36,
 );
 
 sub get_command_type {
