@@ -1,24 +1,21 @@
 package Javonet::Sdk::Core::Type;
 use strict;
 use warnings FATAL => 'all';
-use Exporter;
-
-our @ISA = qw(Exporter);
-our @EXPORT = qw(get_type);
-
+use Moose;
 
 my %my_type = (
     'Command' => 0,
     'JavonetString' => 1,
     'JavonetInteger' => 2,
-    'JavonetBoolean' => 3,
+    'JavonetBool' => 3,
     'JavonetFloat' => 4,
-    'JavonetBytes' => 5,
+    'JavonetByte' => 5,
     'JavonetChar' => 6,
     'JavonetLongLong' => 7,
     'JavonetDouble' => 8,
     'JavonetUnsignedLongLong' => 9,
-    'JavonetUnsignedInteger' => 10
+    'JavonetUnsignedInteger' => 10,
+    'JavonetNull' => 11,
 );
 
 sub get_type {
@@ -26,4 +23,6 @@ sub get_type {
     return $my_type{$type};
 }
 
+no Moose;
+
 1;
\ No newline at end of file
